@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2011  Oliver Burn
+// Copyright (C) 2001-2012  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -133,7 +133,10 @@ public class JavadocTag
     public boolean canReferenceImports()
     {
         return (JavadocTagInfo.SEE.equals(mTagInfo)
-                || JavadocTagInfo.LINK.equals(mTagInfo));
+                || JavadocTagInfo.LINK.equals(mTagInfo)
+                || JavadocTagInfo.LINKPLAIN.equals(mTagInfo)
+                || JavadocTagInfo.THROWS.equals(mTagInfo)
+                || JavadocTagInfo.EXCEPTION.equals(mTagInfo));
     }
 }
 
