@@ -20,4 +20,9 @@ public class InputTrailingComment {
         /* comment before text */int z;
         /* int y */int y/**/;
     }
+
+    /**
+     * comment with trailing space 
+     */
+    final static public String NAME="Some Name"; // NOI18N
 }
