@@ -1,6 +1,6 @@
 package  com.puppycrawl.tools.checkstyle.coding;
 
-public class ReturnFromFinallyCheckTestInput {
+public class InputReturnFromFinallyCheck {
     public void foo() {
         try {
             System.currentTimeMillis();
@@ -18,4 +18,9 @@ public class ReturnFromFinallyCheckTestInput {
             }
         }
     }
+    public void thisNull() {
+        boolean result = (this == null) || (null == this);
+        boolean result2 = (this != null) && (null != this);
+        boolean result3 = (this.getClass().getName() == String.valueOf(null == System.getProperty("abc")));
+    }
 }
