@@ -2,21 +2,21 @@ public class InputValidAssignIndent
 {
     void foo(String[] args)
     {
-        i = 1 +
+        int i = 1 +
             2 +
             3;
         String line = mIndentCheck[
             getLineNo()];
         String line1 =
-            getLineNo();
+            getLine();
         line1 =
-            getLineNo();
-        int i 
+            getLine();
+        int i1 
             =
             1;
         i = 3;
 
-        brace =
+        Integer brace =
             (candidate == SLIST)
             ? candidate : null;
 
@@ -31,10 +31,30 @@ public class InputValidAssignIndent
                 public void bar() {
                 }
             };
+// XXX: need to be fixed
+//         function.lastArgument().candidate = parameters;
+//         function.lastArgument().candidate
+//             =
+//             parameters;
         // TODO: add more testing
     }
 
     private interface AnInterfaceFooWithALongName {
         void bar();
     }
+
+    private static final int SLIST = 1;
+    private static final int parameters = 1;
+    int candidate = 0;
+    private String[] mIndentCheck = null;
+    private InputValidAssignIndent function = null;
+    int getLineNo() {
+        return 1;
+    }
+    String getLine() {
+        return "";
+    }
+    InputValidAssignIndent lastArgument() {
+        return this;
+    }
 }
