@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2011  Oliver Burn
+// Copyright (C) 2001-2012  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -731,4 +731,16 @@ public class IndentationCheckTest extends BaseCheckTestSupport
         final String[] expected = {};
         verify(checkConfig, getPath("Input15Extensions.java"), expected);
     }
+
+    @Test
+    public void testTryResources() throws Exception
+    {
+        final DefaultConfiguration checkConfig =
+            createCheckConfig(IndentationCheck.class);
+        final String[] expected = {
+            //"something is expected, but there is nothing",
+        };
+        verify(checkConfig, getPath("indentation/InputValidTryResourcesIndent.java"),
+               expected);
+    }
 }
