@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2011  Oliver Burn
+// Copyright (C) 2001-2012  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -49,6 +49,7 @@ public class JavadocPackageCheckTest
             getSrcPath("checks/javadoc/BadCls.java"),
             expected);
     }
+
     @Test
     public void testBoth() throws Exception
     {
@@ -83,4 +84,14 @@ public class JavadocPackageCheckTest
             getPath("javadoc/pkghtml/Ignored.java"),
             getPath("javadoc/pkghtml/package-info.java"), expected);
     }
+
+    @Test
+    public void testAnnotation() throws Exception
+    {
+        final DefaultConfiguration checkConfig = createCheckConfig(JavadocPackageCheck.class);
+        final String[] expected = {};
+        verify(createChecker(checkConfig),
+            getPath("javadoc/pkginfo/annotation/package-info.java"),
+            getPath("javadoc/pkginfo/annotation/package-info.java"), expected);
+    }
 }
